@@ -4,8 +4,8 @@ PREFIX="${PRINTNANNY_PREFIX:-.tmp/test}"
 
 KEYS="${PREFIX}/keys"
 mkdir -p "$KEYS"
-openssl ecparam -genkey -name prime256v1 -noout -out "${KEYS}/id_ecdsa"
-openssl ec -in "${KEYS}/id_ecdsa" -pubout -out "${KEYS}/id_ecdsa.pub"
+openssl ecparam -genkey -name prime256v1 -noout -out "${KEYS}/ec_private.pem"
+openssl ec -in "${KEYS}/ec_private.pem" -pubout -out "${KEYS}/ec_public.pem"
 
 echo "Creating ${KEYS}/janus_admin_secret"
 echo "test_janus_admin_secret" > "${KEYS}/janus_admin_secret"
